[Libreoffice] [PATCH] Renamed SwAttrIter to SwWW8AttrIter to avoid a name conflict

nthiebaud at gmail.com nthiebaud at gmail.com
Mon Oct 4 05:53:11 PDT 2010


SwAttrIter is used in the ww8 filter but is also defined in
sw/source/core/text/itrtxt.hxx
this rename the former to make sure there is no posible confusion.
---
 sw/source/filter/ww8/docxattributeoutput.cxx |    2 +-
 sw/source/filter/ww8/rtfexport.cxx           |    2 +-
 sw/source/filter/ww8/wrtw8nds.cxx            |   36 +++++++++++++-------------
 sw/source/filter/ww8/wrtww8.hxx              |   14 +++++-----
 4 files changed, 27 insertions(+), 27 deletions(-)

diff --git a/sw/source/filter/ww8/docxattributeoutput.cxx b/sw/source/filter/ww8/docxattributeoutput.cxx
index 18f8712..b5d79f2 100644
--- a/sw/source/filter/ww8/docxattributeoutput.cxx
+++ b/sw/source/filter/ww8/docxattributeoutput.cxx
@@ -826,7 +826,7 @@ void DocxAttributeOutput::StartRuby( const SwTxtNode& rNode, xub_StrLen nPos, co
     m_pSerializer->startElementNS( XML_w, XML_rt, FSEND );
     StartRun( NULL );
     StartRunProperties( );
-    SwAttrIter aAttrIt( m_rExport, rNode );
+    SwWW8AttrIter aAttrIt( m_rExport, rNode );
     aAttrIt.OutAttr( nPos, true );
     USHORT nStyle = m_rExport.GetId( *rRuby.GetTxtRuby()->GetCharFmt() );
     OString aStyleId( "style" );
diff --git a/sw/source/filter/ww8/rtfexport.cxx b/sw/source/filter/ww8/rtfexport.cxx
index 6e92224..43a0f02 100644
--- a/sw/source/filter/ww8/rtfexport.cxx
+++ b/sw/source/filter/ww8/rtfexport.cxx
@@ -817,7 +817,7 @@ OString RtfExport::OutChar(sal_Unicode c, int *pUCMode, rtl_TextEncoding eDestEn
 {
     OStringBuffer aBuf;
     const sal_Char* pStr = 0;
-    // 0x0b instead of \n, etc because of the replacements in SwAttrIter::GetSnippet()
+    // 0x0b instead of \n, etc because of the replacements in SwWW8AttrIter::GetSnippet()
     switch (c)
     {
         case 0x0b:
diff --git a/sw/source/filter/ww8/wrtw8nds.cxx b/sw/source/filter/ww8/wrtw8nds.cxx
index 66222b7..5c295de 100644
--- a/sw/source/filter/ww8/wrtw8nds.cxx
+++ b/sw/source/filter/ww8/wrtw8nds.cxx
@@ -178,7 +178,7 @@ public:
     }
 };
 
-void SwAttrIter::IterToCurrent()
+void SwWW8AttrIter::IterToCurrent()
 {
     ASSERT(maCharRuns.begin() != maCharRuns.end(), "Impossible");
     mnScript = maCharRunIter->mnScript;
@@ -186,7 +186,7 @@ void SwAttrIter::IterToCurrent()
     mbCharIsRTL = maCharRunIter->mbRTL;
 }
 
-SwAttrIter::SwAttrIter(MSWordExportBase& rWr, const SwTxtNode& rTxtNd) :
+SwWW8AttrIter::SwWW8AttrIter(MSWordExportBase& rWr, const SwTxtNode& rTxtNd) :
     MSWordAttrIter(rWr),
     rNd(rTxtNd),
     maCharRuns(GetPseudoCharRuns(rTxtNd, 0, !rWr.HackIsWW8OrHigher())),
@@ -253,7 +253,7 @@ xub_StrLen lcl_getMinPos( xub_StrLen pos1, xub_StrLen pos2 )
     return min;
 }
 
-xub_StrLen SwAttrIter::SearchNext( xub_StrLen nStartPos )
+xub_StrLen SwWW8AttrIter::SearchNext( xub_StrLen nStartPos )
 {
     xub_StrLen nPos;
     xub_StrLen nMinPos = STRING_MAXLEN;
@@ -393,7 +393,7 @@ bool lcl_isFontsizeItem( const SfxPoolItem& rItem )
             rItem.Which( ) == RES_CHRATR_CTL_FONTSIZE );
 }
 
-void SwAttrIter::OutAttr( xub_StrLen nSwPos, bool bRuby )
+void SwWW8AttrIter::OutAttr( xub_StrLen nSwPos, bool bRuby )
 {
     m_rExport.AttrOutput().RTLAndCJKState( IsCharRTL(), GetScript() );
 
@@ -522,7 +522,7 @@ void SwAttrIter::OutAttr( xub_StrLen nSwPos, bool bRuby )
     }
 }
 
-void SwAttrIter::OutFlys(xub_StrLen nSwPos)
+void SwWW8AttrIter::OutFlys(xub_StrLen nSwPos)
 {
     /*
      #i2916#
@@ -544,7 +544,7 @@ void SwAttrIter::OutFlys(xub_StrLen nSwPos)
     }
 }
 
-bool SwAttrIter::IsTxtAttr( xub_StrLen nSwPos )
+bool SwWW8AttrIter::IsTxtAttr( xub_StrLen nSwPos )
 {
     // search for attrs with CH_TXTATR
     if (const SwpHints* pTxtAttrs = rNd.GetpSwpHints())
@@ -560,7 +560,7 @@ bool SwAttrIter::IsTxtAttr( xub_StrLen nSwPos )
     return false;
 }
 
-bool SwAttrIter::IsDropCap( int nSwPos )
+bool SwWW8AttrIter::IsDropCap( int nSwPos )
 {
     // see if the current position falls on a DropCap
     int nDropChars = mrSwFmtDrop.GetChars();
@@ -579,7 +579,7 @@ bool SwAttrIter::IsDropCap( int nSwPos )
     return false;
 }
 
-bool SwAttrIter::RequiresImplicitBookmark()
+bool SwWW8AttrIter::RequiresImplicitBookmark()
 {
     SwImplBookmarksIter bkmkIterEnd = m_rExport.maImplicitBookmarks.end();
     for ( SwImplBookmarksIter aIter = m_rExport.maImplicitBookmarks.begin(); aIter != bkmkIterEnd; ++aIter )
@@ -598,7 +598,7 @@ bool SwAttrIter::RequiresImplicitBookmark()
 // Attribut-Anfangposition fragen kann.
 // Es koennen nur Attribute mit Ende abgefragt werden.
 // Es wird mit bDeep gesucht
-const SfxPoolItem* SwAttrIter::HasTextItem( USHORT nWhich ) const
+const SfxPoolItem* SwWW8AttrIter::HasTextItem( USHORT nWhich ) const
 {
     const SfxPoolItem* pRet = 0;
     const SwpHints* pTxtAttrs = rNd.GetpSwpHints();
@@ -631,7 +631,7 @@ void WW8Export::GetCurrentItems(WW8Bytes& rItems) const
         rItems.Insert((*pO)[nI], rItems.Count());
 }
 
-const SfxPoolItem& SwAttrIter::GetItem(USHORT nWhich) const
+const SfxPoolItem& SwWW8AttrIter::GetItem(USHORT nWhich) const
 {
     const SfxPoolItem* pRet = HasTextItem(nWhich);
     return pRet ? *pRet : rNd.SwCntntNode::GetAttr(nWhich);
@@ -1019,7 +1019,7 @@ String BookmarkToWriter(const String &rBookmark)
         INetURLObject::DECODE_UNAMBIGUOUS, RTL_TEXTENCODING_ASCII_US);
 }
 
-void SwAttrIter::OutSwFmtRefMark(const SwFmtRefMark& rAttr, bool)
+void SwWW8AttrIter::OutSwFmtRefMark(const SwFmtRefMark& rAttr, bool)
 {
     if ( m_rExport.HasRefToObject( REF_SETREFATTR, &rAttr.GetRefName(), 0 ) )
         m_rExport.AppendBookmark( m_rExport.GetBookmarkName( REF_SETREFATTR,
@@ -1119,7 +1119,7 @@ void AttributeOutputBase::TOXMark( const SwTxtNode& rNode, const SwTOXMark& rAtt
         FieldVanish( sTxt, eType );
 }
 
-int SwAttrIter::OutAttrWithRange(xub_StrLen nPos)
+int SwWW8AttrIter::OutAttrWithRange(xub_StrLen nPos)
 {
     int nRet = 0;
     if ( const SwpHints* pTxtAttrs = rNd.GetpSwpHints() )
@@ -1180,7 +1180,7 @@ int SwAttrIter::OutAttrWithRange(xub_StrLen nPos)
     return nRet;
 }
 
-bool SwAttrIter::IsRedlineAtEnd( xub_StrLen nEnd ) const
+bool SwWW8AttrIter::IsRedlineAtEnd( xub_StrLen nEnd ) const
 {
     bool bRet = false;
     // search next Redline
@@ -1202,7 +1202,7 @@ bool SwAttrIter::IsRedlineAtEnd( xub_StrLen nEnd ) const
     return bRet;
 }
 
-const SwRedlineData* SwAttrIter::GetRedline( xub_StrLen nPos )
+const SwRedlineData* SwWW8AttrIter::GetRedline( xub_StrLen nPos )
 {
     if( pCurRedline )
     {
@@ -1397,7 +1397,7 @@ Convert characters that need to be converted, the basic replacements and the
 ridicously complicated title case attribute mapping to hardcoded upper case
 because word doesn't have the feature
 */
-String SwAttrIter::GetSnippet(const String &rStr, xub_StrLen nAktPos,
+String SwWW8AttrIter::GetSnippet(const String &rStr, xub_StrLen nAktPos,
     xub_StrLen nLen) const
 {
     String aSnippet(rStr, nAktPos, nLen);
@@ -1593,7 +1593,7 @@ void WW8AttributeOutput::FormatDrop( const SwTxtNode& rNode, const SwFmtDrop &rS
     m_rWW8Export.pO->Remove( 0, m_rWW8Export.pO->Count() );
 }
 
-xub_StrLen MSWordExportBase::GetNextPos( SwAttrIter* aAttrIter, const SwTxtNode& rNode, xub_StrLen nAktPos  )
+xub_StrLen MSWordExportBase::GetNextPos( SwWW8AttrIter* aAttrIter, const SwTxtNode& rNode, xub_StrLen nAktPos  )
 {
     // Get the bookmarks for the normal run
     xub_StrLen nNextPos = aAttrIter->WhereNext();
@@ -1606,7 +1606,7 @@ xub_StrLen MSWordExportBase::GetNextPos( SwAttrIter* aAttrIter, const SwTxtNode&
     return std::min( nNextPos, nNextBookmark );
 }
 
-void MSWordExportBase::UpdatePosition( SwAttrIter* aAttrIter, xub_StrLen nAktPos, xub_StrLen /*nEnd*/ )
+void MSWordExportBase::UpdatePosition( SwWW8AttrIter* aAttrIter, xub_StrLen nAktPos, xub_StrLen /*nEnd*/ )
 {
     xub_StrLen nNextPos;
 
@@ -1735,7 +1735,7 @@ void MSWordExportBase::OutputTextNode( const SwTxtNode& rNode )
     // have to remember it in nStyle
     USHORT nStyle = nStyleBeforeFly;
 
-    SwAttrIter aAttrIter( *this, rNode );
+    SwWW8AttrIter aAttrIter( *this, rNode );
     rtl_TextEncoding eChrSet = aAttrIter.GetCharSet();
 
     if ( bStartTOX )
diff --git a/sw/source/filter/ww8/wrtww8.hxx b/sw/source/filter/ww8/wrtww8.hxx
index 94d6505..3ca8b8b 100644
--- a/sw/source/filter/ww8/wrtww8.hxx
+++ b/sw/source/filter/ww8/wrtww8.hxx
@@ -740,10 +740,10 @@ protected:
     virtual void ExportDocument_Impl() = 0;
 
     /// Get the next position in the text node to output
-    virtual xub_StrLen GetNextPos( SwAttrIter* pAttrIter, const SwTxtNode& rNode, xub_StrLen nAktPos );
+    virtual xub_StrLen GetNextPos( SwWW8AttrIter* pAttrIter, const SwTxtNode& rNode, xub_StrLen nAktPos );
 
     /// Update the information for GetNextPos().
-    virtual void UpdatePosition( SwAttrIter* pAttrIter, xub_StrLen nAktPos, xub_StrLen nEnd );
+    virtual void UpdatePosition( SwWW8AttrIter* pAttrIter, xub_StrLen nAktPos, xub_StrLen nEnd );
 
     /// Output SwTxtNode
     void OutputTextNode( const SwTxtNode& );
@@ -1411,7 +1411,7 @@ public:
     rtl_TextEncoding GetNodeCharSet() const     { return eNdChrSet; }
 };
 
 // Die Klasse SwAttrIter ist eine Hilfe zum Aufbauen der Fkp.chpx.
 // Dabei werden nur Zeichen-Attribute beachtet; Absatz-Attribute brauchen
 // diese Behandlung nicht.
 // Die Absatz- und Textattribute des Writers kommen rein, und es wird
@@ -1420,7 +1420,7 @@ public:
 // ein Attribut ohne Ende und mit \xff im Text befindet.
 // Mit OutAttr() werden die Attribute an der angegebenen SwPos
 // ausgegeben.
-class SwAttrIter : public MSWordAttrIter
+class SwWW8AttrIter : public MSWordAttrIter
 {
 private:
     const SwTxtNode& rNd;
@@ -1451,10 +1451,10 @@ private:
     void IterToCurrent();
 
     //No copying
-    SwAttrIter(const SwAttrIter&);
-    SwAttrIter& operator=(const SwAttrIter&);
+    SwWW8AttrIter(const SwWW8AttrIter&);
+    SwWW8AttrIter& operator=(const SwWW8AttrIter&);
 public:
-    SwAttrIter( MSWordExportBase& rWr, const SwTxtNode& rNd );
+    SwWW8AttrIter( MSWordExportBase& rWr, const SwTxtNode& rNd );
 
     bool IsTxtAttr( xub_StrLen nSwPos );
     bool IsRedlineAtEnd( xub_StrLen nPos ) const;
@@ -1411,7 +1411,7 @@ public:
 };
 
-// Die Klasse SwAttrIter ist eine Hilfe zum Aufbauen der Fkp.chpx.
+// Die Klasse SwWW8AttrIter ist eine Hilfe zum Aufbauen der Fkp.chpx.
 // Dabei werden nur Zeichen-Attribute beachtet; Absatz-Attribute brauchen
 // diese Behandlung nicht.
-- 
1.7.1



More information about the LibreOffice mailing list